# /usr/bin/env python

# This file is part of pyspring.

# pyspring is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# pyspring is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with pyspring.  If not, see <http://www.gnu.org/licenses/>.

from statistics import mean


def right_justify(sentence, length):
    current_length = len(sentence)
    return " " * (length - current_length) + sentence


def sum_to(length, is_even):
    total_numbers = []
    for counter in range(1, length + 1):
        if (is_even and counter % 2 == 0) or (not is_even and counter % 2 == 1):
            total_numbers.append(counter)
    return sum(total_numbers)


def is_right_angled(*lengths):
    lengths = sorted(lengths)
    if lengths[0] ** 2 + lengths[1] ** 2 == lengths[2] ** 2:
        return True
    return False


def draw_grid(square_width, square_height):
    start_line = ("*---" * square_width) + "*"
    middle_line = ("|   " * square_width) + "|"

    for total_counter in range(0, square_height):
        print(start_line)
        print(middle_line)
        print(middle_line)
    print(start_line)


def user_summarise():
    position_number = 1
    number_list = []
    while True:
        current_number = float(input("Enter number no.{}: ".format(position_number)))
        if current_number < 0:
            print("")
            print("Maximum number:", max(number_list))
            print("Minimum number:", min(number_list))
            print("Mean:", mean(number_list))
            return
        number_list.append(current_number)
        position_number += 1


def is_power(power, base):
    if base == 0 and power != 1:
        return False
    while power/base == power//base:
        power /= base
    if power == 1:
        return True
    return False


def is_sorted(user_list):
    if sorted(user_list) == user_list:
        return True
    return False


def power_sum():
    current_number = 0
    while True:
        for power_counter in range(2, 200):
            if sum(int(counter) for counter in str((current_number ** power_counter))) == current_number:
                print('{0}^{1} = {2}'.format(current_number, power_counter, current_number ** power_counter))
                break
        current_number += 1




# /usr/bin/env python

# This file is part of pyspring.

# pyspring is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# pyspring is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with pyspring.  If not, see <http://www.gnu.org/licenses/>.


def is_palindrome(number):
    number = str(number)
    if len(number) == 1:
        return True
    number_middle = len(number) // 2  # Integer rather than float
    # `reversed` converts to a list
    if number[:number_middle] == "".join(reversed(number[-number_middle:])):
        return True
    return False


def partial_palindrome(number, palindrome_digits):
    if is_palindrome(str(number)[-palindrome_digits:]):
        return True
    return False

# Palindrome problem done by hand
# 198888
# 198889
# 198890
# 198891



# /usr/bin/env python

# This file is part of pyspring.

# pyspring is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# pyspring is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with pyspring.  If not, see <http://www.gnu.org/licenses/>.

from random import randint
total_guesses = 0


def user_guesser(mode, length, number):
    user_number = str(input('Enter a {0} digit number: '.format(length)))
    global total_guesses
    total_guesses += 1
    correct_positions = []
    for char_pos in range(0, length):
        if user_number[char_pos] == number[char_pos]:
            correct_positions.append(str(char_pos + 1))
    if len(correct_positions) == length:
        print('Congratulations, you won in {0} guesses!'.format(total_guesses))
        return
    if mode == 'easy':
        print('')
        print('Incorrect')
        if not correct_positions:
            print('No correct positions\n')
        else:
            print('Correct positions:', ' '.join(correct_positions) + '\n')
        user_guesser('easy', 4, number)
    elif mode == 'normal':
        print('')
        print('Incorrect\n')
        user_guesser('normal', 4, number)
    else:
        print('')
        print('Incorrect\n')
        user_guesser('hard', 5, number)


if __name__ == '__main__':
    user_lengths = {'hard': 5, 'normal': 4, 'easy': 4}
    user_mode = input('Enter a mode (Easy/Normal/Hard): ').lower()
    if user_mode == 'hard':
        computer_number = str(randint(10000, 99999))
    else:
        computer_number = str(randint(1000, 9999))
    user_guesser(user_mode, user_lengths[user_mode], computer_number)



# /usr/bin/env python

# This file is part of pyspring.

# Types-and-Variables is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# pyspring is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with pyspring.  If not, see <http://www.gnu.org/licenses/>.

# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

with open("README.md") as f:
    long_description = f.read()

setup(
    name="pyspring",
    version="0.0.2",
    description="Functions that function",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="harens",
    license="GPLv3",
    packages=find_packages(exclude=("tests",)),
    author_email="harensdeveloper@gmail.com",
    url="https://harens.github.io",
    download_url="https://github.com/harens/pyspring/archive/master.zip",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Operating System :: OS Independent",
        "Intended Audience :: Information Technology",
        "Intended Audience :: Education",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    project_urls={
        "Source": "https://github.com/harens/pyspring",
        "Tracker": "https://github.com/harens/pyspring/issues",
    },
    keywords="Functions, Spring, Test",
)
